@@ -462,7 +462,7 @@ dir.create(comparison_dir)
 
 if(group2 != 'NULL'){
   df_w <- df_longer %>% 
-    pivot_wider(names_from = all_of(group2), values_from = all_off(group2), names_prefix = 'GRP_') %>% 
+    pivot_wider(names_from = all_of(group2), values_from = all_of(group2), names_prefix = 'GRP_') %>% 
     select(Mass, HC, OC, contains('GRP_')) %>% 
     group_by(Mass) %>% 
     fill(contains('GRP_'), .direction = 'downup')  %>% 
